get_coefficient_name: Creates coefficient variable name by converting to camel...

View source: R/get_coefficient_name.R

get_coefficient_nameR Documentation

Creates coefficient variable name by converting to camel case, adding a prefix and removing symbols

Description

Creates coefficient variable name by converting to camel case, adding a prefix and removing symbols

Usage

get_coefficient_name(name, prefix = "coef")

Arguments

name

Raw coefficient name

prefix

Prefix before the name of the coefficient. Should be in camel case

Value

Converted coefficient name


bairdj/lm2sql documentation built on April 5, 2022, 12:05 a.m.